import applescript from 'highlight.js/lib/languages/applescript';
import bash from 'highlight.js/lib/languages/bash';
import csharp from 'highlight.js/lib/languages/csharp';
import c from 'highlight.js/lib/languages/c';
import cpp from 'highlight.js/lib/languages/cpp';
import css from 'highlight.js/lib/languages/css';
import dart from 'highlight.js/lib/languages/dart';
import dockerfile from 'highlight.js/lib/languages/dockerfile';
import fsharp from 'highlight.js/lib/languages/fsharp';
import go from 'highlight.js/lib/languages/go';
import xml from 'highlight.js/lib/languages/xml';
import haskell from 'highlight.js/lib/languages/haskell';
import json from 'highlight.js/lib/languages/json';
import java from 'highlight.js/lib/languages/java';
import javascript from 'highlight.js/lib/languages/javascript';
import kotlin from 'highlight.js/lib/languages/kotlin';
import latex from 'highlight.js/lib/languages/latex';
import makefile from 'highlight.js/lib/languages/makefile';
import markdown from 'highlight.js/lib/languages/markdown';
import php from 'highlight.js/lib/languages/php';
import perl from 'highlight.js/lib/languages/perl';
import python from 'highlight.js/lib/languages/python';
import ruby from 'highlight.js/lib/languages/ruby';
import rust from 'highlight.js/lib/languages/rust';
import scss from 'highlight.js/lib/languages/scss';
import sql from 'highlight.js/lib/languages/sql';
import scala from 'highlight.js/lib/languages/scala';
import { svelte } from './fn/svelte.js';
import swift from 'highlight.js/lib/languages/swift';
import { terraform } from './fn/terraform.js';
import typescript from 'highlight.js/lib/languages/typescript';
import { vba } from './fn/vba.js';
import yaml from 'highlight.js/lib/languages/yaml';
import { zig } from './fn/zig.js';
/**
 * Syntax Highlighting Code Language
 */
export class Language {
    name;
    fn;
    extensions;
    /**
     * @param name The name of the language
     * @param fn The function that highlights the code
     * @param extensions The file extensions that the language supports
     */
    constructor(name, fn, extensions) {
        this.name = name;
        this.fn = fn;
        this.extensions = extensions;
    }
    static appleScript = new Language('applescript', applescript, [
        '.applescript',
        '.scpt',
        '.scptd'
    ]);
    static bash = new Language('bash', bash, ['.sh', '.bash', '.zsh']);
    static csharp = new Language('csharp', csharp, ['.cs']);
    static c = new Language('c', c, ['.c']);
    static cpp = new Language('cpp', cpp, ['.cpp', '.cxx', '.cc', '.h', '.hpp']);
    static css = new Language('css', css, ['.css']);
    static dart = new Language('dart', dart, ['.dart']);
    static dockerfile = new Language('dockerfile', dockerfile, ['Dockerfile']);
    static fsharp = new Language('fsharp', fsharp, ['.fs', '.fsx', '.fsi']);
    static go = new Language('go', go, ['.go']);
    static xml = new Language('xml', xml, ['.xml', '.html', '.xhtml', '.rss', '.atom']);
    static haskell = new Language('haskell', haskell, ['.hs']);
    static json = new Language('json', json, ['.json']);
    static java = new Language('java', java, ['.java']);
    static javascript = new Language('javascript', javascript, [
        '.js',
        '.jsx',
        '.mjs',
        '.cjs'
    ]);
    static kotlin = new Language('kotlin', kotlin, ['.kt', '.kts']);
    static latex = new Language('latex', latex, ['.tex']);
    static makefile = new Language('makefile', makefile, ['Makefile']);
    static markdown = new Language('markdown', markdown, ['.md']);
    static php = new Language('php', php, ['.php']);
    static perl = new Language('perl', perl, ['.plx', '.pls', '.pl', '.pm', '.xs']);
    static python = new Language('python', python, ['.py']);
    static ruby = new Language('ruby', ruby, ['.rb', '.ru']);
    static rust = new Language('rust', rust, ['.rs']);
    static scss = new Language('scss', scss, ['.scss']);
    static sql = new Language('sql', sql, ['.sql']);
    static scala = new Language('scala', scala, ['.scala']);
    static svelte = new Language('svelte', svelte, ['.svelte']);
    static swift = new Language('swift', swift, ['.swift']);
    static terraform = new Language('terraform', terraform, ['.tf', '.tfvars']);
    static typescript = new Language('typescript', typescript, ['.ts', '.tsx']);
    static vba = new Language('vba', vba, ['.vba']);
    static yaml = new Language('yaml', yaml, ['.yaml', '.yml']);
    static zig = new Language('zig', zig, ['.zig']);
    static allCases = [
        this.appleScript,
        this.bash,
        this.csharp,
        this.c,
        this.cpp,
        this.css,
        this.dart,
        this.dockerfile,
        this.fsharp,
        this.go,
        this.xml,
        this.haskell,
        this.json,
        this.java,
        this.javascript,
        this.kotlin,
        this.latex,
        this.makefile,
        this.markdown,
        this.php,
        this.perl,
        this.python,
        this.ruby,
        this.rust,
        this.scss,
        this.scala,
        this.svelte,
        this.swift,
        this.terraform,
        this.typescript,
        this.vba,
        this.yaml,
        this.zig
    ];
}
